Replace use of the term host with server

This patchset focuses on the global store use for server power
operations and impacts several pages in the interface.

For consistency, both in the UI and the code base, we are replacing
the term host with server. This change impacts both the user and the
developer experience. Maintaining consistency in naming allows both
developers and users to form a mental model of the overall system
and will help remove confusion when interacting with the UI and
editing the interface.

Testing:
1. Tested shutdown, power on, and reboot and verified the icons and
page sections in the site header and the server power operations page
update as expected during power operations.
2. Verified the one-time boot operations alert is displayed to the
user when changing the boot settings on the server power operations page
3 Tested factory reset and validated the correct information message
is displayed to the user with the server power off and on when
performing the factory reset functions.
4. Verified the SOL Console status icon updates correctly during
power operations.
5. Verified the alert message is displayed on the firmware update page
when the server is powered on.

Signed-off-by: Derick Montague <derick.montague@ibm.com>
Change-Id: I88499a746364ab80f16a8b350d550407d094e95d
diff --git a/src/store/modules/Control/ControlStore.js b/src/store/modules/Control/ControlStore.js
index 5f532d0..9b8bf73 100644
--- a/src/store/modules/Control/ControlStore.js
+++ b/src/store/modules/Control/ControlStore.js
@@ -2,23 +2,23 @@
 import i18n from '@/i18n';
 
 /**
  * Watch for hostStatus changes in GlobalStore module
  * to set isOperationInProgress state
  * Stop watching status changes and resolve Promise when
  * hostStatus value matches passed argument or after 5 minutes
  * @param {string} hostStatus
  * @returns {Promise}
  */
-const checkForHostStatus = function (hostStatus) {
+const checkForServerStatus = function (serverStatus) {
   return new Promise((resolve) => {
     const timer = setTimeout(() => {
       resolve();
       unwatch();
     }, 300000 /*5mins*/);
     const unwatch = this.watch(
-      (state) => state.global.hostStatus,
+      (state) => state.global.serverStatus,
       (value) => {
-        if (value === hostStatus) {
+        if (value === serverStatus) {
           resolve();
           unwatch();
           clearTimeout(timer);
@@ -82,42 +82,42 @@
           throw new Error(i18n.t('pageRebootBmc.toast.errorRebootStart'));
         });
     },
-    async hostPowerOn({ dispatch, commit }) {
+    async serverPowerOn({ dispatch, commit }) {
       const data = { ResetType: 'On' };
-      dispatch('hostPowerChange', data);
-      await checkForHostStatus.bind(this, 'on')();
+      dispatch('serverPowerChange', data);
+      await checkForServerStatus.bind(this, 'on')();
       commit('setOperationInProgress', false);
       dispatch('getLastPowerOperationTime');
     },
-    async hostSoftReboot({ dispatch, commit }) {
+    async serverSoftReboot({ dispatch, commit }) {
       const data = { ResetType: 'GracefulRestart' };
-      dispatch('hostPowerChange', data);
-      await checkForHostStatus.bind(this, 'on')();
+      dispatch('serverPowerChange', data);
+      await checkForServerStatus.bind(this, 'on')();
       commit('setOperationInProgress', false);
       dispatch('getLastPowerOperationTime');
     },
-    async hostHardReboot({ dispatch, commit }) {
+    async serverHardReboot({ dispatch, commit }) {
       const data = { ResetType: 'ForceRestart' };
-      dispatch('hostPowerChange', data);
-      await checkForHostStatus.bind(this, 'on')();
+      dispatch('serverPowerChange', data);
+      await checkForServerStatus.bind(this, 'on')();
       commit('setOperationInProgress', false);
       dispatch('getLastPowerOperationTime');
     },
-    async hostSoftPowerOff({ dispatch, commit }) {
+    async serverSoftPowerOff({ dispatch, commit }) {
       const data = { ResetType: 'GracefulShutdown' };
-      dispatch('hostPowerChange', data);
-      await checkForHostStatus.bind(this, 'off')();
+      dispatch('serverPowerChange', data);
+      await checkForServerStatus.bind(this, 'off')();
       commit('setOperationInProgress', false);
       dispatch('getLastPowerOperationTime');
     },
-    async hostHardPowerOff({ dispatch, commit }) {
+    async serverHardPowerOff({ dispatch, commit }) {
       const data = { ResetType: 'ForceOff' };
-      dispatch('hostPowerChange', data);
-      await checkForHostStatus.bind(this, 'off')();
+      dispatch('serverPowerChange', data);
+      await checkForServerStatus.bind(this, 'off')();
       commit('setOperationInProgress', false);
       dispatch('getLastPowerOperationTime');
     },
-    hostPowerChange({ commit }, data) {
+    serverPowerChange({ commit }, data) {
       commit('setOperationInProgress', true);
       api
         .post('/redfish/v1/Systems/system/Actions/ComputerSystem.Reset', data)
@@ -2,23 +2,23 @@
 
 /**
- * Watch for hostStatus changes in GlobalStore module
+ * Watch for serverStatus changes in GlobalStore module
  * to set isOperationInProgress state
  * Stop watching status changes and resolve Promise when
@@ -2,23 +2,23 @@
  * to set isOperationInProgress state
  * Stop watching status changes and resolve Promise when
- * hostStatus value matches passed argument or after 5 minutes
- * @param {string} hostStatus
+ * serverStatus value matches passed argument or after 5 minutes
+ * @param {string} serverStatus
  * @returns {Promise}
  */